@@ -11,22 +11,24 @@ sub new {
 }
 
 ### B_{i,n} are Bernstein polynomials, see bernsteinpolynomialsalgorithm.pm
+### it uses a simple xyz coordinate list as a point for the bezier curve
+### One can use this with a nested list of points
 sub calculate {
-	my ($self, @Bin, @Points) = @_;
+	my ($self, @Bin, @Pointxyz) = @_;
 
 	my $p = point->new(0,0,0);
-	my $l = length(@Points); 
+	my $l = length(@Pointxyz); 
 
 	while (--$l >= 0) {
-		$p->setx($p->getx + @Bin[$l]*@Points[$l]);
+		$p->setx($p->getx + @Bin[$l]*@Pointxyz[$l]);
 	}
 
 	while (--$l >= 0) {
-		$p->sety($p->gety + @Bin[$l]*@Points[$l]);
+		$p->sety($p->gety + @Bin[$l]*@Pointxyz[$l]);
 	}
 
 	while (--$l >= 0) {
-		$p->setz($p->getz + @Bin[$l]*@Points[$l]);
+		$p->setz($p->getz + @Bin[$l]*@Pointxyz[$l]);
 	}
 
 	return $p;
